@@ -1,44 +1,12 @@
 use strict;
 use warnings;
-
 package Math::TotalBuilder::Common;
+{
+  $Math::TotalBuilder::Common::VERSION = '1.102';
+}
+# ABSTRACT: common unit sets for building totals
 
-=head1 NAME
 
-Math::TotalBuilder::Common -- common unit sets for building totals
-
-=head1 VERSION
-
-version 1.101
-
- $Id: /my/cs/projects/total/trunk/lib/Math/TotalBuilder/Common.pm 27913 2006-11-13T15:50:51.155685Z rjbs  $
-
-=cut
-
-our $VERSION = '1.101';
-
-=head1 SYNOPSIS
-
- use Math::TotalBuilder;
- use Math::TotalBuilder::Common;
-
- # units for 952 pence
- my %tender = build($Math::TotalBuilder::Common::uk_money_old, 952);
-
-=head1 DESCRIPTION
-
-This package is just a set of common sets of units for use with the code in
-Math::TotalBuilder.
-
-=cut
-
-=head1 Unit Sets
-
-=head2 currency_us
-
-United States currency: dollar bills, coins.  The base unit is a penny.
-
-=cut
 
 our $currency_us = { ## no critic PackageVar
   hundred => 10000,
@@ -55,11 +23,6 @@ our $currency_us = { ## no critic PackageVar
   penny   =>     1
 };
 
-=head2 time
-
-Units of time: week, day, hour, minute, second.  The base unit is a second.
-
-=cut
 
 our $time = { ## no critic PackageVar
   week    => 604_800,
@@ -69,15 +32,52 @@ our $time = { ## no critic PackageVar
   second  =>       1
 };
 
+"Here's your change.";
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Math::TotalBuilder::Common - common unit sets for building totals
+
+=head1 VERSION
+
+version 1.102
+
+=head1 SYNOPSIS
+
+ use Math::TotalBuilder;
+ use Math::TotalBuilder::Common;
+
+ # units for 952 pence
+ my %tender = build($Math::TotalBuilder::Common::uk_money_old, 952);
+
+=head1 DESCRIPTION
+
+This package is just a set of common sets of units for use with the code in
+Math::TotalBuilder.
+
+=head1 Unit Sets
+
+=head2 currency_us
+
+United States currency: dollar bills, coins.  The base unit is a penny.
+
+=head2 time
+
+Units of time: week, day, hour, minute, second.  The base unit is a second.
+
 =head1 AUTHOR
 
-Ricardo SIGNES, E<lt>rjbs@cpan.orgE<gt>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-This is free software, and can be distributed under the same terms as perl
-itself.
+This software is copyright (c) 2004 by Ricardo SIGNES.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-"Here's your change.";
